@@ -112,7 +112,7 @@ class GPasteIndicator extends PanelMenu.Button {
         if (event.has_control_modifier()) {
             const nb = parseInt(event.get_key_unicode());
             if (!isNaN(nb) && nb >= 0 && nb <= 9 && nb < this._history.length) {
-                this._history[nb].activate();
+                this._history[nb].activate(event);
             }
         } else {
             this._maybeUpdateIndexVisibility(event, true);
@@ -165,11 +165,10 @@ class GPasteIndicator extends PanelMenu.Button {
                 }
 
                 this._history.slice(0, results - offset).forEach((i, index) => {
-                    i.setIndex(this._searchResults[offset + index]);
+                    i.setUuid(this._searchResults[offset + index]);
                 });
 
-                /* If we had no result, updateForSize would have returned false */
-                this._dummyHistoryItem.hide();
+                this._updateVisibility(results == 0);
 
                 this._history.slice(results - offset, maxSize).forEach(function(i) {
                     i.setIndex(-1);
@@ -282,7 +281,7 @@ class GPasteIndicator extends PanelMenu.Button {
         }
     }
 
-    _updateVisibility(empty, search) {
+    _updateVisibility(empty) {
         if (!empty) {
             this._dummyHistoryItem.hide();
             this._emptyHistoryItem.show();
@@ -343,9 +342,13 @@ class GPasteIndicator extends PanelMenu.Button {
         } else {
             this._updateIndexVisibility(false);
         }
+        super._onOpenStateChanged(menu, state);
     }
 
     _onMenuKeyPress(actor, event) {
+        if(this._switch.active)
+            return super._onMenuKeyPress(actor, event);
+
         const symbol = event.get_key_symbol();
         if (symbol == Clutter.KEY_Left) {
             return this._pageSwitcher.previous();
